# -*- coding: utf-8 -*-
# Created by lvjiyong on 16/8/20


def sign_up(request):
    """
    注册帐号
    :param request:
    :return:
    """
    pass


def sign_in(request):
    pass


def sign_out(request):
    pass


def change_password(request):
    pass


def change_email(request):
    pass


def change_profile(request):
    pass


def change_detail(request):
    pass
